package com.gic.enterprise.interceptor;

import com.alibaba.fastjson.JSON;
import com.gic.enterprise.constants.Constants;
import com.gic.enterprise.context.UserContext;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.exception.CommonException;
import com.gic.enterprise.utils.UserDetail;
import com.gic.enterprise.utils.UserDetailUtils;
import org.apache.dubbo.rpc.RpcContext;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.Map;


public class AuthInterceptor extends HandlerInterceptorAdapter {

    private static final Logger log = LogManager.getLogger(AuthInterceptor.class);

    private static final Map<String, Object> ignoreUriMap = new HashMap<>(16);
    static {
        ignoreUriMap.put("/gic-auth-web/login", "1");
        ignoreUriMap.put("/gic-auth-web/logout", "1");
        ignoreUriMap.put("/gic-auth-web/list-enterprise-by-phone", "1");
        ignoreUriMap.put("/gic-auth-web/login-user-menu", "1");
        ignoreUriMap.put("/gic-auth-web/login-user-operation-item", "1");
    }

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object object) throws Exception {
        String token = UserContext.getContext().getToken();
        RpcContext.getContext().getAttachments().put(Constants.USER_TOKEN, token);
        System.out.println(JSON.toJSONString(RpcContext.getContext().getArguments()));

        //获取uri
        String uri = request.getRequestURI();
        log.info("用户接口访问路由：{}", uri);
        //不需要拦截的路径
        if (ignoreUriMap.containsKey(uri)) {
            return true;
        }
        //判断是否有权限的路径
        UserDetail userDetail = UserDetailUtils.getUserDetail();
        Map<String, Object> menuUrlMap = userDetail.getMenuUrlMap();
        if (menuUrlMap == null || menuUrlMap.isEmpty()) {
            throw new CommonException(ErrorCode.SYSTEM_ERROR.getErrorCode(), "sorry，您无该页面的访问权限，请联系超级管理员！");
        }
        if (!menuUrlMap.containsKey(uri)) {
            throw new CommonException(ErrorCode.SYSTEM_ERROR.getErrorCode(), "sorry，您无该页面的访问权限，请联系超级管理员！");
        }

        return true;
    }
}
